#[non_exhaustive]pub struct Comment {
pub id: CommentId,
pub body: String,
pub url: String,
pub user: Option<UserRef>,
pub created_at: OffsetDateTime,
pub edited_at: Option<OffsetDateTime>,
pub resolved_at: Option<OffsetDateTime>,
pub parent: Option<CommentParent>,
}Expand description
One comment on an issue.
Wire shape: the canonical fragment
fragment CommentFields on Comment { id body url user { ...UserRefFields } createdAt editedAt resolvedAt parent { id } }.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.id: CommentIdComment ID.
body: StringThe comment content, in markdown.
url: StringURL of the comment on linear.app.
user: Option<UserRef>The author. None for some integration-authored comments (e.g. bots
posting via createAsUser).
created_at: OffsetDateTimeWhen the comment was created.
edited_at: Option<OffsetDateTime>When the comment was last edited, if ever.
resolved_at: Option<OffsetDateTime>When the comment thread was resolved, if it has been.
parent: Option<CommentParent>The parent comment when this comment is a threaded reply.