IssueUpdateInputBuilder

Struct IssueUpdateInputBuilder 

pub struct IssueUpdateInputBuilder<S: State = Empty> { /* private fields */ }
Use builder syntax to set the inputs and finish with build().

Implementations

Source

impl<S: State> IssueUpdateInputBuilder<S>

pub fn build(self) -> IssueUpdateInput
where S: IsComplete,

Finish building and return the requested object

pub fn title( self, value: impl Into<String>, ) -> IssueUpdateInputBuilder<SetTitle<S>>
where S::Title: IsUnset,

Optional (Some / Option setters). New title.

pub fn maybe_title( self, value: Option<impl Into<String>>, ) -> IssueUpdateInputBuilder<SetTitle<S>>
where S::Title: IsUnset,

Optional (Some / Option setters). New title.

pub fn state_id( self, value: WorkflowStateId, ) -> IssueUpdateInputBuilder<SetStateId<S>>
where S::StateId: IsUnset,

Optional (Some / Option setters). New workflow state.

pub fn maybe_state_id( self, value: Option<WorkflowStateId>, ) -> IssueUpdateInputBuilder<SetStateId<S>>
where S::StateId: IsUnset,

Optional (Some / Option setters). New workflow state.

pub fn priority( self, value: Priority, ) -> IssueUpdateInputBuilder<SetPriority<S>>
where S::Priority: IsUnset,

Optional (Some / Option setters). New priority.

pub fn maybe_priority( self, value: Option<Priority>, ) -> IssueUpdateInputBuilder<SetPriority<S>>
where S::Priority: IsUnset,

Optional (Some / Option setters). New priority.

pub fn sort_order(self, value: f64) -> IssueUpdateInputBuilder<SetSortOrder<S>>
where S::SortOrder: IsUnset,

Optional (Some / Option setters). New board sort order.

pub fn maybe_sort_order( self, value: Option<f64>, ) -> IssueUpdateInputBuilder<SetSortOrder<S>>
where S::SortOrder: IsUnset,

Optional (Some / Option setters). New board sort order.

pub fn label_ids( self, value: Vec<LabelId>, ) -> IssueUpdateInputBuilder<SetLabelIds<S>>
where S::LabelIds: IsUnset,

Optional (Some / Option setters). Replace the full label set. Prefer added_label_ids / removed_label_ids.

pub fn maybe_label_ids( self, value: Option<Vec<LabelId>>, ) -> IssueUpdateInputBuilder<SetLabelIds<S>>
where S::LabelIds: IsUnset,

Optional (Some / Option setters). Replace the full label set. Prefer added_label_ids / removed_label_ids.

pub fn added_label_ids( self, value: Vec<LabelId>, ) -> IssueUpdateInputBuilder<SetAddedLabelIds<S>>
where S::AddedLabelIds: IsUnset,

Optional (Some / Option setters). Labels to add, keeping existing ones.

pub fn maybe_added_label_ids( self, value: Option<Vec<LabelId>>, ) -> IssueUpdateInputBuilder<SetAddedLabelIds<S>>
where S::AddedLabelIds: IsUnset,

Optional (Some / Option setters). Labels to add, keeping existing ones.

pub fn removed_label_ids( self, value: Vec<LabelId>, ) -> IssueUpdateInputBuilder<SetRemovedLabelIds<S>>
where S::RemovedLabelIds: IsUnset,

Optional (Some / Option setters). Labels to remove, keeping the rest.

pub fn maybe_removed_label_ids( self, value: Option<Vec<LabelId>>, ) -> IssueUpdateInputBuilder<SetRemovedLabelIds<S>>
where S::RemovedLabelIds: IsUnset,

Optional (Some / Option setters). Labels to remove, keeping the rest.

pub fn description( self, value: impl Into<Undefinable<String>>, ) -> IssueUpdateInputBuilder<SetDescription<S>>
where S::Description: IsUnset,

Optional (Some / Option setters). Default: <Undefinable<String> as Default>::default().

Description in markdown.

Live-verified server quirk: Linear ignores null for this document-backed field — Undefinable::Null is a no-op here. To clear the description, set it to an empty string.

pub fn maybe_description( self, value: Option<impl Into<Undefinable<String>>>, ) -> IssueUpdateInputBuilder<SetDescription<S>>
where S::Description: IsUnset,

Optional (Some / Option setters). Default: <Undefinable<String> as Default>::default().

Description in markdown.

Live-verified server quirk: Linear ignores null for this document-backed field — Undefinable::Null is a no-op here. To clear the description, set it to an empty string.

pub fn assignee_id( self, value: impl Into<Undefinable<UserId>>, ) -> IssueUpdateInputBuilder<SetAssigneeId<S>>
where S::AssigneeId: IsUnset,

Optional (Some / Option setters). Default: <Undefinable<UserId> as Default>::default().

Assignee (Undefinable::Null unassigns).

pub fn maybe_assignee_id( self, value: Option<impl Into<Undefinable<UserId>>>, ) -> IssueUpdateInputBuilder<SetAssigneeId<S>>
where S::AssigneeId: IsUnset,

Optional (Some / Option setters). Default: <Undefinable<UserId> as Default>::default().

Assignee (Undefinable::Null unassigns).

pub fn estimate( self, value: impl Into<Undefinable<i64>>, ) -> IssueUpdateInputBuilder<SetEstimate<S>>
where S::Estimate: IsUnset,

Optional (Some / Option setters). Default: <Undefinable<i64> as Default>::default().

Estimate (Undefinable::Null clears it).

pub fn maybe_estimate( self, value: Option<impl Into<Undefinable<i64>>>, ) -> IssueUpdateInputBuilder<SetEstimate<S>>
where S::Estimate: IsUnset,

Optional (Some / Option setters). Default: <Undefinable<i64> as Default>::default().

Estimate (Undefinable::Null clears it).

pub fn project_id( self, value: impl Into<Undefinable<ProjectId>>, ) -> IssueUpdateInputBuilder<SetProjectId<S>>
where S::ProjectId: IsUnset,

Optional (Some / Option setters). Default: <Undefinable<ProjectId> as Default>::default().

Project (Undefinable::Null removes the issue from its project).

pub fn maybe_project_id( self, value: Option<impl Into<Undefinable<ProjectId>>>, ) -> IssueUpdateInputBuilder<SetProjectId<S>>
where S::ProjectId: IsUnset,

Optional (Some / Option setters). Default: <Undefinable<ProjectId> as Default>::default().

Project (Undefinable::Null removes the issue from its project).

pub fn project_milestone_id( self, value: impl Into<Undefinable<ProjectMilestoneId>>, ) -> IssueUpdateInputBuilder<SetProjectMilestoneId<S>>
where S::ProjectMilestoneId: IsUnset,

Optional (Some / Option setters). Default: <Undefinable<ProjectMilestoneId> as Default>::default().

Project milestone (Undefinable::Null clears it).

pub fn maybe_project_milestone_id( self, value: Option<impl Into<Undefinable<ProjectMilestoneId>>>, ) -> IssueUpdateInputBuilder<SetProjectMilestoneId<S>>
where S::ProjectMilestoneId: IsUnset,

Optional (Some / Option setters). Default: <Undefinable<ProjectMilestoneId> as Default>::default().

Project milestone (Undefinable::Null clears it).

pub fn cycle_id( self, value: impl Into<Undefinable<CycleId>>, ) -> IssueUpdateInputBuilder<SetCycleId<S>>
where S::CycleId: IsUnset,

Optional (Some / Option setters). Default: <Undefinable<CycleId> as Default>::default().

Cycle (Undefinable::Null removes the issue from its cycle).

pub fn maybe_cycle_id( self, value: Option<impl Into<Undefinable<CycleId>>>, ) -> IssueUpdateInputBuilder<SetCycleId<S>>
where S::CycleId: IsUnset,

Optional (Some / Option setters). Default: <Undefinable<CycleId> as Default>::default().

Cycle (Undefinable::Null removes the issue from its cycle).

pub fn parent_id( self, value: impl Into<Undefinable<IssueId>>, ) -> IssueUpdateInputBuilder<SetParentId<S>>
where S::ParentId: IsUnset,

Optional (Some / Option setters). Default: <Undefinable<IssueId> as Default>::default().

Parent issue (Undefinable::Null promotes it to a top-level issue).

pub fn maybe_parent_id( self, value: Option<impl Into<Undefinable<IssueId>>>, ) -> IssueUpdateInputBuilder<SetParentId<S>>
where S::ParentId: IsUnset,

Optional (Some / Option setters). Default: <Undefinable<IssueId> as Default>::default().

Parent issue (Undefinable::Null promotes it to a top-level issue).

pub fn due_date( self, value: impl Into<Undefinable<TimelessDate>>, ) -> IssueUpdateInputBuilder<SetDueDate<S>>
where S::DueDate: IsUnset,

Optional (Some / Option setters). Default: <Undefinable<TimelessDate> as Default>::default().

Due date (Undefinable::Null clears it).

pub fn maybe_due_date( self, value: Option<impl Into<Undefinable<TimelessDate>>>, ) -> IssueUpdateInputBuilder<SetDueDate<S>>
where S::DueDate: IsUnset,

Optional (Some / Option setters). Default: <Undefinable<TimelessDate> as Default>::default().

Due date (Undefinable::Null clears it).