Module labels

Module labels 

Issue labels: listing, create/update/delete, and the LabelsService::ensure find-or-create convenience.

Structs

Label
An issue label.
LabelCreateInput
Input for LabelsService::create (IssueLabelCreateInput).
LabelCreateInputBuilder
Use builder syntax to set the inputs and finish with build().
LabelUpdateInput
Input for LabelsService::update (IssueLabelUpdateInput).
LabelUpdateInputBuilder
Use builder syntax to set the inputs and finish with build().
LabelsService
Issue label operations. Obtain via LinearClient::labels.
ListLabelsRequest
Variables for LabelsService::list.
ListLabelsRequestBuilder
Use builder syntax to set the inputs and finish with build().