ProjectUpdateInputBuilder

Struct ProjectUpdateInputBuilder 

pub struct ProjectUpdateInputBuilder<S: State = Empty> { /* private fields */ }
Use builder syntax to set the inputs and finish with build().

Implementations

Source

impl<S: State> ProjectUpdateInputBuilder<S>

pub fn build(self) -> ProjectUpdateInput
where S: IsComplete,

Finish building and return the requested object

pub fn name(self, value: String) -> ProjectUpdateInputBuilder<SetName<S>>
where S::Name: IsUnset,

Optional (Some / Option setters). New project name.

pub fn maybe_name( self, value: Option<String>, ) -> ProjectUpdateInputBuilder<SetName<S>>
where S::Name: IsUnset,

Optional (Some / Option setters). New project name.

pub fn description( self, value: String, ) -> ProjectUpdateInputBuilder<SetDescription<S>>
where S::Description: IsUnset,

Optional (Some / Option setters). New short description.

pub fn maybe_description( self, value: Option<String>, ) -> ProjectUpdateInputBuilder<SetDescription<S>>
where S::Description: IsUnset,

Optional (Some / Option setters). New short description.

pub fn status_id( self, value: ProjectStatusId, ) -> ProjectUpdateInputBuilder<SetStatusId<S>>
where S::StatusId: IsUnset,

Optional (Some / Option setters). New project status.

pub fn maybe_status_id( self, value: Option<ProjectStatusId>, ) -> ProjectUpdateInputBuilder<SetStatusId<S>>
where S::StatusId: IsUnset,

Optional (Some / Option setters). New project status.

pub fn priority( self, value: Priority, ) -> ProjectUpdateInputBuilder<SetPriority<S>>
where S::Priority: IsUnset,

Optional (Some / Option setters). New project priority.

pub fn maybe_priority( self, value: Option<Priority>, ) -> ProjectUpdateInputBuilder<SetPriority<S>>
where S::Priority: IsUnset,

Optional (Some / Option setters). New project priority.

pub fn team_ids( self, value: Vec<TeamId>, ) -> ProjectUpdateInputBuilder<SetTeamIds<S>>
where S::TeamIds: IsUnset,

Optional (Some / Option setters). New set of teams.

pub fn maybe_team_ids( self, value: Option<Vec<TeamId>>, ) -> ProjectUpdateInputBuilder<SetTeamIds<S>>
where S::TeamIds: IsUnset,

Optional (Some / Option setters). New set of teams.

pub fn content( self, value: impl Into<Undefinable<String>>, ) -> ProjectUpdateInputBuilder<SetContent<S>>
where S::Content: IsUnset,

Optional (Some / Option setters). Default: <Undefinable<String> as Default>::default().

Long-form markdown content.

Live-verified server quirk: Linear ignores both null and the empty string for this document-backed field — neither Undefinable::Null nor "" clears it; only non-empty values update it.

pub fn maybe_content( self, value: Option<impl Into<Undefinable<String>>>, ) -> ProjectUpdateInputBuilder<SetContent<S>>
where S::Content: IsUnset,

Optional (Some / Option setters). Default: <Undefinable<String> as Default>::default().

Long-form markdown content.

Live-verified server quirk: Linear ignores both null and the empty string for this document-backed field — neither Undefinable::Null nor "" clears it; only non-empty values update it.

pub fn lead_id( self, value: impl Into<Undefinable<UserId>>, ) -> ProjectUpdateInputBuilder<SetLeadId<S>>
where S::LeadId: IsUnset,

Optional (Some / Option setters). Default: <Undefinable<UserId> as Default>::default().

Project lead (clearable).

pub fn maybe_lead_id( self, value: Option<impl Into<Undefinable<UserId>>>, ) -> ProjectUpdateInputBuilder<SetLeadId<S>>
where S::LeadId: IsUnset,

Optional (Some / Option setters). Default: <Undefinable<UserId> as Default>::default().

Project lead (clearable).

pub fn start_date( self, value: impl Into<Undefinable<TimelessDate>>, ) -> ProjectUpdateInputBuilder<SetStartDate<S>>
where S::StartDate: IsUnset,

Optional (Some / Option setters). Default: <Undefinable<TimelessDate> as Default>::default().

Planned start date (clearable).

pub fn maybe_start_date( self, value: Option<impl Into<Undefinable<TimelessDate>>>, ) -> ProjectUpdateInputBuilder<SetStartDate<S>>
where S::StartDate: IsUnset,

Optional (Some / Option setters). Default: <Undefinable<TimelessDate> as Default>::default().

Planned start date (clearable).

pub fn target_date( self, value: impl Into<Undefinable<TimelessDate>>, ) -> ProjectUpdateInputBuilder<SetTargetDate<S>>
where S::TargetDate: IsUnset,

Optional (Some / Option setters). Default: <Undefinable<TimelessDate> as Default>::default().

Planned target date (clearable).

pub fn maybe_target_date( self, value: Option<impl Into<Undefinable<TimelessDate>>>, ) -> ProjectUpdateInputBuilder<SetTargetDate<S>>
where S::TargetDate: IsUnset,

Optional (Some / Option setters). Default: <Undefinable<TimelessDate> as Default>::default().

Planned target date (clearable).